
# dpkt

The dpkt project is a python module for fast, simple packet parsing, with definitions for the basic TCP/IP protocols.

### Installation
```
pip install dpkt
```

### Examples
- [Print Packets](print_packets.md)
- [Print ICMP](print_icmp.md)
- [Print HTTP](print_http_requests.md)

### Documentation
- [DPKT Key Concepts for Creating Parsers](creating_parsers.md)
- [Changelog](changelog.md)
- [Authors](authors.md)
- [Contributing](contributing.md)
- [Project Plans (TBD)](plans.md)
- [Admin Notes](admin_notes.md)

## About
This code is based on [dpkt code](https://code.google.com/p/dpkt/) lead by Dug Song and is now being maintained and improved by an extended set of [developers] (https://github.com/kbandla/dpkt/graphs/contributors).

## LICENSE

BSD 3-Clause
